svn commit: r952187 - /ofbiz/trunk/applications/party/src/org/ofbiz/party/party/PartyRelationshipHelper.java

Previous Topic Next Topic
 
classic Classic list List threaded Threaded
1 message Options
Reply | Threaded
Open this post in threaded view
|

svn commit: r952187 - /ofbiz/trunk/applications/party/src/org/ofbiz/party/party/PartyRelationshipHelper.java

jleroux@apache.org
Author: jleroux
Date: Mon Jun  7 11:28:57 2010
New Revision: 952187

URL: http://svn.apache.org/viewvc?rev=952187&view=rev
Log:
Revert r949820, was not complete

Modified:
    ofbiz/trunk/applications/party/src/org/ofbiz/party/party/PartyRelationshipHelper.java

Modified: ofbiz/trunk/applications/party/src/org/ofbiz/party/party/PartyRelationshipHelper.java
URL: http://svn.apache.org/viewvc/ofbiz/trunk/applications/party/src/org/ofbiz/party/party/PartyRelationshipHelper.java?rev=952187&r1=952186&r2=952187&view=diff
==============================================================================
--- ofbiz/trunk/applications/party/src/org/ofbiz/party/party/PartyRelationshipHelper.java (original)
+++ ofbiz/trunk/applications/party/src/org/ofbiz/party/party/PartyRelationshipHelper.java Mon Jun  7 11:28:57 2010
@@ -19,14 +19,21 @@
 
 package org.ofbiz.party.party;
 
+import java.sql.Timestamp;
 import java.util.List;
 import java.util.Map;
 
+import javolution.util.FastList;
+
 import org.ofbiz.base.util.Debug;
+import org.ofbiz.base.util.UtilDateTime;
+import org.ofbiz.base.util.UtilMisc;
+import org.ofbiz.base.util.UtilValidate;
 import org.ofbiz.entity.Delegator;
 import org.ofbiz.entity.GenericEntityException;
 import org.ofbiz.entity.GenericValue;
-import org.ofbiz.entity.util.EntityUtil;
+import org.ofbiz.entity.condition.EntityCondition;
+import org.ofbiz.entity.condition.EntityOperator;
 
 /**
  * PartyRelationshipHelper
@@ -35,48 +42,44 @@ public class PartyRelationshipHelper {
 
     public static final String module = PartyRelationshipHelper.class.getName();
 
/**
* Return A List of the active Party Relationships
*
* @param delegator
* @param partyRelationshipValues Map containing the input parameters
* @return List of the active Party Relationships
      */
-    public static List<GenericValue> getPartyRelationships(Delegator delegator, Map<String, ?> partyRelationshipValues) {
-        return getPartyRelationships(delegator, partyRelationshipValues, true);
-    }
+    public static List<GenericValue> getActivePartyRelationships(Delegator delegator, Map<String, ?> partyRelationshipValues) {
+        String partyIdFrom = (String) partyRelationshipValues.get("partyIdFrom") ;
+        String partyIdTo = (String) partyRelationshipValues.get("partyIdTo") ;
+        String roleTypeIdFrom = (String) partyRelationshipValues.get("roleTypeIdFrom") ;
+        String roleTypeIdTo = (String) partyRelationshipValues.get("roleTypeIdTo") ;
+        String partyRelationshipTypeId = (String) partyRelationshipValues.get("partyRelationshipTypeId") ;
+        Timestamp fromDate = UtilDateTime.nowTimestamp();
+
+        List<EntityCondition> condList = FastList.newInstance();
+        condList.add(EntityCondition.makeCondition("partyIdFrom", partyIdFrom));
+        condList.add(EntityCondition.makeCondition("partyIdTo", partyIdTo));
+        condList.add(EntityCondition.makeCondition("roleTypeIdFrom", roleTypeIdFrom));
+        condList.add(EntityCondition.makeCondition("roleTypeIdTo", roleTypeIdTo));
+        condList.add(EntityCondition.makeCondition("partyRelationshipTypeId", partyRelationshipTypeId));
+        condList.add(EntityCondition.makeCondition("fromDate", EntityOperator.LESS_THAN_EQUAL_TO, fromDate));
+        EntityCondition thruCond = EntityCondition.makeCondition(UtilMisc.toList(
+                EntityCondition.makeCondition("thruDate", null),
+                EntityCondition.makeCondition("thruDate", EntityOperator.GREATER_THAN, fromDate)),
+                EntityOperator.OR);
+        condList.add(thruCond);
+        EntityCondition condition = EntityCondition.makeCondition(condList);
 
-    /**
-     * Return A List of the Party Relationships
-     *
-     * @param delegator
-     * @param partyRelationshipValues Map containing the input parameters
-     * @param activeOnly
-     * @return List of the active Party Relationships
-     */
-    public static List<GenericValue> getPartyRelationships(Delegator delegator, Map<String, ?> partyRelationshipValues, boolean activeOnly) {
         List<GenericValue> partyRelationships = null;
         try {
-            partyRelationships = delegator.findByAndCache("PartyRelationship", partyRelationshipValues);
-            if (activeOnly){
-                partyRelationships = EntityUtil.filterByDate(partyRelationships);
-            }
+            partyRelationships = delegator.findList("PartyRelationship", condition, null, null, null, false);
         } catch (GenericEntityException e) {
             Debug.logError(e, "Problem finding PartyRelationships. ", module);
+            return null;
+        }
+        if (UtilValidate.isNotEmpty(partyRelationships)) {
+           return partyRelationships;
+        } else {
+            return null;
         }
-
-        return partyRelationships;
-    }
-
-    @Deprecated
-    /**
-     * Return A List of the active Party Relationships (ie with valid from and thru dates)
-     *
-     * @param delegator needed Delegator
-     * @param partyRelationshipValues Map containing the input parameters (primaries keys + partyRelationshipTypeId)
-     * @return List of the active Party Relationships
-     */
-    public static List<GenericValue> getActivePartyRelationships(Delegator delegator, Map<String, ?> partyRelationshipValues) {
-        return getPartyRelationships(delegator, partyRelationshipValues, true);
     }
 }
@@ -35,48 +42,44 @@ public class PartyRelationshipHelper {
     public static final String module = PartyRelationshipHelper.class.getName();
 
-    /**
-     * Return A List of the active Party Relationships
-     *
-     * @param delegator
-     * @param partyRelationshipValues Map containing the input parameters
-     * @return List of the active Party Relationships
+    /** Return A List of the active Party Relationships (ie with valid from and thru dates)
+     *@param delegator needed Delegator
+     *@param partyRelationshipValues Map containing the input parameters (primaries keys + partyRelationshipTypeId)
+     *@return List of the active Party Relationships
      */